@@ -1,6 +1,3 @@
-
-from __future__ import print_function
-
 __doc__ = """GNUmed database backend listener.
 
 This module implements threaded listening for asynchronuous
@@ -27,9 +24,9 @@ _log = logging.getLogger('gm.db')
 
 
 signals2listen4 = [
-	u'db_maintenance_warning',		# warns of impending maintenance and asks for disconnect
-	u'db_maintenance_disconnect',	# announces a forced disconnect and disconnects
-	u'gm_table_mod'					# sent for any (registered) table modification, payload contains details
+	'db_maintenance_warning',		# warns of impending maintenance and asks for disconnect
+	'db_maintenance_disconnect',	# announces a forced disconnect and disconnects
+	'gm_table_mod'					# sent for any (registered) table modification, payload contains details
 ]
 
 #=====================================================================
@@ -40,6 +37,7 @@ class gmBackendListener(gmBorg.cBorg):
 		try:
 			self.already_inited
 			return
+
 		except AttributeError:
 			pass
 
@@ -98,16 +96,16 @@ class gmBackendListener(gmBorg.cBorg):
 				if self._listener_thread.isAlive():
 					_log.error('listener thread still alive after join()')
 					_log.debug('active threads: %s' % threading.enumerate())
-			except:
+			except Exception:
 				pass
-		except:
+		except Exception:
 			print(sys.exc_info())
 
 		self._listener_thread = None
 
 		try:
 			self.__unregister_unspecific_notifications()
-		except:
+		except Exception:
 			_log.exception('unable to unregister unspecific notifications')
 
 		self.__shutdown_connection()
@@ -156,9 +154,8 @@ class gmBackendListener(gmBorg.cBorg):
 		self._conn_lock.acquire(1)
 		try:
 			self._conn.rollback()
-			self._conn.close()
-		except:
-			pass				# connection can already be closed :-(
+		except Exception:
+			pass
 		finally:
 			self._conn_lock.release()
 
@@ -169,9 +166,9 @@ class gmBackendListener(gmBorg.cBorg):
 
 		self._listener_thread = threading.Thread (
 			target = self._process_notifications,
-			name = self.__class__.__name__
+			name = self.__class__.__name__,
+			daemon = True
 		)
-		self._listener_thread.setDaemon(True)
 		_log.info('starting listener thread')
 		self._listener_thread.start()
 
@@ -183,7 +180,6 @@ class gmBackendListener(gmBorg.cBorg):
 		# loop until quitting
 		_have_quit_lock = None
 		while not _have_quit_lock:
-
 			# quitting ?
 			if self._quit_lock.acquire(0):
 				break
@@ -194,21 +190,18 @@ class gmBackendListener(gmBorg.cBorg):
 				ready_input_sockets = select.select([self._conn_fd], [], [], self._poll_interval)[0]
 			finally:
 				self._conn_lock.release()
-
 			# any input available ?
 			if len(ready_input_sockets) == 0:
 				# no, select.select() timed out
 				# give others a chance to grab the conn lock (eg listen/unlisten)
 				time.sleep(0.3)
 				continue
-
 			# data available, wait for it to fully arrive
 			self._conn_lock.acquire(1)
 			try:
 				self._conn.poll()
 			finally:
 				self._conn_lock.release()
-
 			# any notifications ?
 			while len(self._conn.notifies) > 0:
 				# if self._quit_lock can be acquired we may be in
@@ -228,26 +221,26 @@ class gmBackendListener(gmBorg.cBorg):
 					print(notification)
 				_log.debug('#%s: %s (first param is PID of sending backend)', self.__notifications_received, notification)
 				# decode payload
-				payload = notification.payload.split(u'::')
+				payload = notification.payload.split('::')
 				operation = None
 				table = None
-				pk_column = None
-				pk_row = None
+				pk_column_name = None
+				pk_of_row = None
 				pk_identity = None
 				for item in payload:
-					if item.startswith(u'operation='):
-						operation = item.split(u'=')[1]
-					if item.startswith(u'table='):
-						table = item.split(u'=')[1]
-					if item.startswith(u'PK name='):
-						pk_column = item.split(u'=')[1]
-					if item.startswith(u'row PK='):
-						pk_row = int(item.split(u'=')[1])
-					if item.startswith(u'person PK='):
+					if item.startswith('operation='):
+						operation = item.split('=')[1]
+					if item.startswith('table='):
+						table = item.split('=')[1]
+					if item.startswith('PK name='):
+						pk_column_name = item.split('=')[1]
+					if item.startswith('row PK='):
+						pk_of_row = int(item.split('=')[1])
+					if item.startswith('person PK='):
 						try:
-							pk_identity = int(item.split(u'=')[1])
+							pk_identity = int(item.split('=')[1])
 						except ValueError:
-							_log.exception(u'error in change notification trigger')
+							_log.exception('error in change notification trigger')
 							pk_identity = -1
 				# try sending intra-client signals:
 				# 1) generic signal
@@ -261,18 +254,18 @@ class gmBackendListener(gmBorg.cBorg):
 						pk_identity = pk_identity,
 						operation = operation,
 						table = table,
-						pk_column = pk_column,
-						pk_row = pk_row,
+						pk_column_name = pk_column_name,
+						pk_of_row = pk_of_row,
 						message_index = self.__messages_sent,
 						notification_index = self.__notifications_received
 					)
-				except:
+				except Exception:
 					print("problem routing notification [%s] from backend [%s] to intra-client dispatcher" % (notification.channel, notification.pid))
 					print(sys.exc_info())
 				# 2) dynamically emulated old style table specific signals
 				if table is not None:
 					self.__messages_sent += 1
-					signal = u'%s_mod_db' % table
+					signal = '%s_mod_db' % table
 					_log.debug('emulating old-style table specific signal [%s]', signal)
 					try:
 						results = gmDispatcher.send (
@@ -283,12 +276,12 @@ class gmBackendListener(gmBorg.cBorg):
 							pk_identity = pk_identity,
 							operation = operation,
 							table = table,
-							pk_column = pk_column,
-							pk_row = pk_row,
+							pk_column_name = pk_column_name,
+							pk_of_row = pk_of_row,
 							message_index = self.__messages_sent,
 							notification_index = self.__notifications_received
 						)
-					except:
+					except Exception:
 						print("problem routing notification [%s] from backend [%s] to intra-client dispatcher" % (signal, notification.pid))
 						print(sys.exc_info())
 
@@ -300,6 +293,7 @@ class gmBackendListener(gmBorg.cBorg):
 
 		# exit thread activity
 		return
+
 #=====================================================================
 # main
 #=====================================================================
@@ -334,7 +328,7 @@ if __name__ == "__main__":
 		#-------------------------------
 		try:
 			n = int(sys.argv[2])
-		except:
+		except Exception:
 			print("You can set the number of iterations\nwith the second command line argument")
 			n = 100000
 
@@ -355,7 +349,7 @@ if __name__ == "__main__":
 		print("Now in a new shell connect psql to the")
 		print("database <gnumed_v9> on localhost, return")
 		print("here and hit <enter> to continue.")
-		raw_input('hit <enter> when done starting psql')
+		input('hit <enter> when done starting psql')
 		print("You now have about 30 seconds to go")
 		print("to the psql shell and type")
 		print(" notify patient_changed<enter>")
@@ -371,7 +365,7 @@ if __name__ == "__main__":
 				counter += 1
 				time.sleep(1)
 				sys.stdout.flush()
-				print('.', end=' ')
+				print('.')
 			print("Looping",n,"times through dummy function")
 			i = 0
 			t1 = time.time()
@@ -399,7 +393,7 @@ if __name__ == "__main__":
 			except KeyError:
 				print('==> received signal from client: "%s"' % kwargs['signal'])
 			del kwargs['signal']
-			for key in kwargs.keys():
+			for key in kwargs:
 				print('    [%s]: %s' % (key, kwargs[key]))
 
 		gmDispatcher.connect(receiver = monitoring_callback)
@@ -417,7 +411,7 @@ if __name__ == "__main__":
 			print("found patient", pat)
 			gmPerson.set_active_patient(patient=pat)
 			print("now waiting for notifications, hit <ENTER> to select another patient")
-			raw_input()
+			input()
 
 		print("cleanup")
 		listener.shutdown()
